PSendFlag

Enum PSendFlag 

pub enum PSendFlag {
    Block,
    NonBlock,
}
Describe the sending flag of the Socket

  • Block : Normal usage of the Socket. Blocking until a message is sent
  • NonBlock : The Socket send does not stop the execution of the program

Variants



Block

Normal usage of the Socket. Blocking until a message is sent



NonBlock

The Socket send does not stop the execution of the program