PMockSocket

Struct PMockSocket 

pub struct PMockSocket { /* private fields */ }
The PMockSocket defines a mock backend which implements the AbstractClockBackend trait and is able to play, record and replay a set of time